pub struct Item {
pub order_item_id: String,
pub quantity: i32,
pub item_weight: Option<Box<Weight>>,
pub item_description: Option<String>,
pub transparency_code_list: Option<Vec<String>>,
pub item_level_seller_inputs_list: Option<Vec<AdditionalSellerInputs>>,
}Expand description
Item : An Amazon order item identifier and a quantity.
Fields
order_item_id: StringAn Amazon-defined identifier for an individual item in an order.
quantity: i32The number of items.
item_weight: Option<Box<Weight>>item_description: Option<String>The description of the item.
transparency_code_list: Option<Vec<String>>A list of transparency codes.
item_level_seller_inputs_list: Option<Vec<AdditionalSellerInputs>>A list of additional seller input pairs required to purchase shipping.
Implementations